Synpurge
========

Utility to remove history of Matrix rooms using the `purge_history API`__
of Synapse__.

__ https://github.com/matrix-org/synapse/blob/master/docs/admin_api/purge_history_api.rst
__ https://github.com/matrix-org/synapse


Licensing
---------

Distributed under the terms of the `GNU General Public License v3`__.

__ https://www.gnu.org/licenses/gpl-3.0.en.html

